from setuptools import setup, version

setup(
    name='lhdis',
    version='0.1.1',
    descriptions='Gaussian(Normal) and Binomial Distributions',
    packages=['lhdis'],
    author='Nyi Nyi Linn Htet',
    author_email='nyi20471@gmail.com',
    zip_safe=False
)